==> 0.1.0-rc.0.tar.gz: lib/src/meeting_uikit/permission/permission_helper.dart <==
// Copyright (c) 2014-2020 NetEase, Inc.
// All right reserved.
part of meeting_uikit;

enum ConfirmAction { cancel, accept }

class PermissionHelper {
  static Future<bool> requestPermissionSingle(
      BuildContext context, Permission permission,String title,String tips,) async {
    PermissionStatus status = await permission.status;
    bool granted = status == PermissionStatus.granted;
    if (granted) return granted;
    final action = await showDialog<ConfirmAction>(
        context: context,
        builder: (BuildContext context) {
          return buildPermissionDialog(context,title,tips);
        });
    if (action == ConfirmAction.accept) {
      granted = await requestSingle(permission);
    }
    return granted;
  }

  static CupertinoAlertDialog buildPermissionDialog(BuildContext context,String title,String tips) {
    return CupertinoAlertDialog(
      title: Text('${UIStrings.notWork}$tips'),
      content: Text(
          '${UIStrings.funcNeed}$tips,${UIStrings.needPermissionTipsFirst}$title${UIStrings.needPermissionTipsTail}$tips${UIStrings.permissionTips}？'),
      actions: <Widget>[
        CupertinoDialogAction(
          child: Text(UIStrings.cancel),
          onPressed: () {
            Navigator.of(context).pop(ConfirmAction.cancel);
          },
        ),
        CupertinoDialogAction(
          child: Text(UIStrings.toSetUp),
          onPressed: () {
            Navigator.of(context).pop(ConfirmAction.accept);
          },
        ),
      ],
    );
  }

  static Future<bool> requestSingle(Permission request) async {
    PermissionStatus status = await request.request();
    if (status.isPermanentlyDenied) {
      openAppSettings();
    }
    return status == PermissionStatus.granted;
  }
}

==> 0.1.1-rc.0.tar.gz: lib/src/meeting_uikit/permission/permission_helper.dart <==
// Copyright (c) 2014-2020 NetEase, Inc.
// All right reserved.
part of meeting_uikit;

enum ConfirmAction { cancel, accept }

class PermissionHelper {
  static Future<bool> requestPermissionSingle(
      BuildContext context, Permission permission,String title,String tips,{bool useDialog = true}) async {
    var status = await permission.status;
    var granted = status == PermissionStatus.granted;
    if (granted) return granted;
    if (useDialog) {
      final action = await showDialog<ConfirmAction>(
          context: context,
          builder: (BuildContext context) {
            return buildPermissionDialog(context, title, tips);
          });
      if (action == ConfirmAction.accept) {
        granted = await requestSingle(permission);
      }
    } else {
      granted = await requestSingle(permission);
    }
    return granted;
  }

  static CupertinoAlertDialog buildPermissionDialog(BuildContext context,String title,String tips) {
    return CupertinoAlertDialog(
      title: Text('${UIStrings.notWork}$tips'),
      content: Text(
          '${UIStrings.funcNeed}$tips,${UIStrings.needPermissionTipsFirst}$title${UIStrings.needPermissionTipsTail}$tips${UIStrings.permissionTips}？'),
      actions: <Widget>[
        CupertinoDialogAction(
          child: Text(UIStrings.cancel),
          onPressed: () {
            Navigator.of(context).pop(ConfirmAction.cancel);
          },
        ),
        CupertinoDialogAction(
          child: Text(UIStrings.toSetUp),
          onPressed: () {
            Navigator.of(context).pop(ConfirmAction.accept);
          },
        ),
      ],
    );
  }

  static Future<bool> requestSingle(Permission request) async {
    PermissionStatus status = await request.request();
    if (status.isPermanentlyDenied) {
      openAppSettings();
    }
    return status == PermissionStatus.granted;
  }
}
